pub enum DaemonRunDirError {
RelativeDataHome {
data_home: PathBuf,
},
}Expand description
Why the daemon run directory could not be resolved.
Variants
RelativeDataHome
The data home resolved to a relative path, which would place the run directory under whatever directory the process was started from.