pub enum ForwardingError {
Show 13 variants
NoModuleConnection,
ModuleReloading {
module_id: String,
},
StaleModuleEndpoint,
UnknownReservation {
client_channel: u16,
module_channel: u16,
},
ClientRouteChannelExhausted {
connection_id: ConnectionId,
},
ModuleRouteChannelExhausted {
endpoint: ModuleEndpointId,
},
RelayCorrelationExhausted,
ConnectionClosing {
connection_id: ConnectionId,
},
ClientEgressClosed {
connection_id: ConnectionId,
},
RouteOpenBuild(String),
CandidateSlotOccupied {
module_id: String,
},
ModuleEgressUnavailable {
connection_id: ConnectionId,
},
Poisoned,
}Variants
NoModuleConnection
ModuleReloading
StaleModuleEndpoint
UnknownReservation
ClientRouteChannelExhausted
Fields

connection_id: ConnectionIdModuleRouteChannelExhausted
Fields

endpoint: ModuleEndpointIdRelayCorrelationExhausted
ConnectionClosing
Fields

connection_id: ConnectionIdClientEgressClosed
Fields

connection_id: ConnectionIdRouteOpenBuild(String)
CandidateSlotOccupied
A swap candidate is already registered for this module id.
A registering module’s HELLO_ACK could not be queued because its outbound queue is closed or full.
Poisoned