pub struct TerminalRing { /* private fields */ }Expand description
Bounded terminal-exit history for one supervised module.
This belongs to the module rather than an individual child so a replacement process retains the exits that caused it to exist.
Implementations
Sourceimpl TerminalRing
impl TerminalRing
pub fn new(config: TerminalRingConfig, daemon_started_at_ms: u64) -> Self
pub fn push(&mut self, entry: TerminalRecord)
pub fn snapshot(&self) -> TerminalHistorySnapshot