BoundDaemon

Struct BoundDaemon 

pub struct BoundDaemon {
    pub listeners: Vec<TcpListener>,
    pub connection_info: ConnectionInfo,
    pub connection_file_path: PathBuf,
    pub connection_file_source: ConnectionFileSource,
    pub machine_id: Option<MachineId>,
    /* private fields */
}

Fields

listeners: Vec<TcpListener>connection_info: ConnectionInfoconnection_file_path: PathBufconnection_file_source: ConnectionFileSourcemachine_id: Option<MachineId>

The machine id this daemon serves, established before any connection is accepted. None when the config named no machine id path.